Index: apps/app_voicemail.c
===================================================================
--- apps/app_voicemail.c	(revision 313046)
+++ apps/app_voicemail.c	(working copy)
@@ -853,6 +853,10 @@
 static char listen_control_restart_key[12];
 static char listen_control_stop_key[12];
 
+/* custom intro sounds */
+static char vm_login[80] = "vm-login";
+static char vm_newuser_sound[80] = "vm-newuser";
+
 /* custom password sounds */
 static char vm_password[80] = "vm-password";
 static char vm_newpassword[80] = "vm-newpassword";
@@ -9632,7 +9636,7 @@
 	adsi_begin(chan, &useadsi);
 	if (!skipuser && useadsi)
 		adsi_login(chan);
-	if (!silent && !skipuser && ast_streamfile(chan, "vm-login", chan->language)) {
+	if (!silent && !skipuser && ast_streamfile(chan, vm_login, chan->language)) {
 		ast_log(AST_LOG_WARNING, "Couldn't stream login file\n");
 		return -1;
 	}
@@ -9974,7 +9978,7 @@
 	/* Check to see if this is a new user */
 	if (!strcasecmp(vmu->mailbox, vmu->password) && 
 		(ast_test_flag(vmu, VM_FORCENAME | VM_FORCEGREET))) {
-		if (ast_play_and_wait(chan, "vm-newuser") == -1)
+		if (ast_play_and_wait(chan, vm_newuser_sound) == -1)
 			ast_log(AST_LOG_WARNING, "Couldn't stream new user file\n");
 		cmd = vm_newuser(chan, vmu, &vms, vmfmts, record_gain);
 		if ((cmd == 't') || (cmd == '#')) {
@@ -12085,6 +12089,12 @@
 			exitcontext[0] = '\0';
 		}
 		
+		/* load configurable intro messages */
+		if ((val = ast_variable_retrieve(cfg, "general", "vm-login")))
+			ast_copy_string(vm_login, val, sizeof(vm_login));
+		if ((val = ast_variable_retrieve(cfg, "general", "vm-newuser")))
+			ast_copy_string(vm_newuser_sound, val, sizeof(vm_newuser_sound));
+
 		/* load password sounds configuration */
 		if ((val = ast_variable_retrieve(cfg, "general", "vm-password")))
 			ast_copy_string(vm_password, val, sizeof(vm_password));
Index: configs/voicemail.conf.sample
===================================================================
--- configs/voicemail.conf.sample	(revision 313046)
+++ configs/voicemail.conf.sample	(working copy)
@@ -294,30 +294,38 @@
                     ; The default is "no".
 ; minpassword=0 ; Enforce minimum password length
 
+; vm-login=custom_sound
+;	Customize which sound file is used instead of the default
+;	file vm-login that says: "Comedian Mail.  Mailbox?"
+; vm-newuser=custom_sound
+;	Customize which sound file is used instead of the default
+;	file vm-newuser that says: "Welcome to Comedian Mail.
+;	First I will guide you through a short setup process."
 ; vm-password=custom_sound
-			;     Customize which sound file is used instead of the default
-			;     prompt that says: "password"
+;	Customize which sound file is used instead of the default
+;	file vm-password that says: "password"
 ; vm-newpassword=custom_sound
-			;     Customize which sound file is used instead of the default
-			;     prompt that says: "Please enter your new password followed by
-			;     the pound key."
+;	Customize which sound file is used instead of the default
+;	file vm-newpassword that says: "Please enter your new password
+;	followed by the pound key."
 ; vm-passchanged=custom_sound
-			;     Customize which sound file is used instead of the default
-			;     prompt that says: "Your password has been changed."
+;	Customize which sound file is used instead of the default
+;	file vm-passchanged that says: "Your passwords have been changed."
 ; vm-reenterpassword=custom_sound
-			;     Customize which sound file is used instead of the default
-			;     prompt that says: "Please re-enter your password followed by
-			;     the pound key"
+;	Customize which sound file is used instead of the default
+;	file vm-reenterpassword that says: "Please re-enter your password
+;	followed by the pound key"
 ; vm-mismatch=custom_sound
-			;     Customize which sound file is used instead of the default
-			;     prompt that says: "The passwords you entered and re-entered
-			;     did not match."
+;	Customize which sound file is used instead of the default
+;	file vm-mismatch that says: "The passwords you entered and re-entered
+;	did not match."
 ; vm-invalid-password=custom_sound
-			;     Customize which sound file is used instead of the default
-			;     prompt that says: ...
+;	Customize which sound file is used instead of the default
+;	file vm-invalid-password that says: "That password does not meet the
+;	minimum requirements for this mailbox." 
 ; vm-pls-try-again=custom_sound
-                        ; Customize which sound file is used instead of the
-                        ; default prompt that says "Please try again."
+;	Customize which sound file is used instead of the default
+;	file vm-pls-try-again that says "Please try again."
 ; listen-control-forward-key=#	; Customize the key that fast-forwards message playback
 ; listen-control-reverse-key=*	; Customize the key that rewinds message playback
 ; listen-control-pause-key=0	; Customize the key that pauses/unpauses message playback
